# pcsg - a constructive solid geometry library for Python

Constructive solid geometry is a technique used for modeling shapes and solids.
The ***pycsg*** library can be used to create 3D printable solid objects, images and animations utilizing external programs like [POV-Ray](http://www.povray.org/) and [OpenScad](https://www.openscad.org/).
Introducing a common description format eleminates the need for learning different scripting languages and rewriting your code.

